<?php
/*
Plugin Name: TRIBE WooCommerce Subscription Events for Klaviyo
Description: Triggers events within Klaviyo for new and cancelled WooCommerce subscriptions.
Version: 1.0.3
Author: Tribe Interactive, LLC
Author URI: https://www.madebytribe.com
*/


define( 'WCK_ROOT', __DIR__ );
define( 'WCK_LOCALE', 'woocommerce-klaviyo' );
if (!defined('WCK_VERSION')) define('WCK_VERSION', '1.0.3');

include WCK_ROOT . '/includes/klaviyo.php';

class WCK_Hooks {

	public function __construct() {
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_settings_link' ) );
		add_action( 'admin_init', [ $this, 'register_settings' ] );
		add_action( 'admin_menu', [ $this, 'add_admin_menu' ] );
		add_action( 'woocommerce_checkout_subscription_created', [ $this, 'subscription_created' ], 10, 1 );
		add_action( 'woocommerce_subscription_status_pending-cancel', [ $this, 'subscription_cancel' ], 10, 1 );
	}

	public function plugin_settings_link( $links ){
		$url = get_admin_url() . 'admin.php?page=wck-sub-events';
		$settings_link = '<a href="'.$url.'">' . __( 'Settings', 'wck' ) . '</a>';
		array_unshift( $links, $settings_link );
		return $links;
	}

	public function register_settings(){
		register_setting('wck-sub-events','wck-api-key');
	}

	public function add_admin_menu(){
		add_menu_page(
	        'Subscription Events',
	        'Subscription Events',
	        'manage_options',
	        'wck-sub-events',
	        array($this,'wck_menu'),
	        'dashicons-filter',
	        65
	    );
	}

	public function wck_menu(){
		//Check vor valid nonce and if valid process options.
		if(isset($_POST['nonce'])){
			if(wp_verify_nonce($_POST['nonce'],'wck-nonce')){
				$this->process_options($_POST);
			}

		}

		settings_fields('wck-sub-events');
		do_settings_sections('wck-sub-events');

		$wck_api_key = get_option('wck-api-key');
		$nonce = wp_create_nonce( 'wck-nonce' );

		$html .= '<div class="wrap">';
			$html .= '<h1>WooCommerce Subscription Events for Klaviyo</h1>';
			$html .= '<p>This plugin will triggers custom events within Klaviyo anytime there is a new or cancelled WooCommerce subscription. It requires both the <a href="https://wordpress.org/plugins/klaviyo/">Klaviyo</a> &amp; <a href="https://woocommerce.com/products/woocommerce-subscriptions/">WooCommerce Subscriptions</a> plugins to be installed and activated.</p>';
			$html .= '<p>Insert your Klaviyo public API key below to connect. You can find it on your Klaviyo <a href="https://www.klaviyo.com/account#api-keys-tab">account</a> page. For more help please visit <a href="https://www.madebytribe.com">madebytribe.com</a>.</p>';
			$html .= '<form method="post" id="wck-form">';
				$html .= '<table class="form-table"><tbody>';
					$html .= '<tr valign="top">';
						$html .= '<th scope="row"><label for="wck-api-key"><strong>Klaviyo Public API Key </strong></label></th>';
						$html .= '<td><input type="text" name="wck-api-key" value="' . $wck_api_key . '"></td>';
					$html .= '</tr>';
				$html .= '</tbody></table>';
				$html .= '<input type="hidden" name="nonce" value="' . $nonce . '">';
				$html .= get_submit_button();
			$html .= '</form>';
		$html .= '</div>';

		return print $html;

	}
	private function process_options($data){
		settings_fields('wck-sub-events');
		do_settings_sections('wck-sub-events');

		$wck_api_key = sanitize_text_field( $data['wck-api-key'] );
		update_option('wck-api-key',$wck_api_key);
	}

	private function get_api_key(){
		$wck_api_key = get_option('wck-api-key');
		return $wck_api_key;
	}

	public function subscription_created( $subscription ) {
		$items = $subscription->get_items();
		$client = new Klaviyo( $this->get_api_key() );

		foreach ( $items as $item ) {
			$is_trial = $this->is_trial( $subscription );
			$response = $client->track(
				'Subscribed to Plan',
				[ '$email' => $subscription->get_billing_email() ],
				[
					'Plan' => $item->get_name(),
					'PlanID' => $item->get_product_id(),
					'PlanType' => $is_trial ? 'Trial' : 'Paid',
					'$value' => $is_trial ? 0 : $subscription->get_total()
				],
				time()
			);
		}
	}

	public function subscription_cancel( $subscription ) {
		$items = $subscription->get_items();
		$client = new Klaviyo( $this->get_api_key() );

		foreach ( $items as $item ) {
			$is_trial = $this->is_trial( $subscription );
			$response = $client->track(
				'Cancelled Plan',
				[ '$email' => $subscription->get_billing_email() ],
				[
					'Plan' => $item->get_name(),
					'PlanID' => $item->get_product_id(),
					'PlanType' => $is_trial ? 'Trial' : 'Paid',
					'$value' => $is_trial ? 0 : $subscription->get_total()
				],
				time()
			);
		}
	}

	private function is_trial( $subscription ) {
		return false != $subscription->get_date( 'trial_end' );
	}

}

$GLOBALS['WCK_Hooks'] = new WCK_Hooks();
